package Database;

################################################################################
# PAD Archiv Demo
# Copyright (c) 2000-2002 by Oliver Grahl Software Design
#
# http://www.o-grahl.de/deupad/
#
# Freeware, Verwendung auf eigene Gefahr.
# Verffentlichung oder Weitergabe nur mit Zustimmung des Autors.
################################################################################
#
# Database.pm
#
# Zweck:
#  Einfache Datenbank fuer Program Objekte, die Daten werden in der Datei
#  database.csv ;-separiert abgelegt.
# Funktionsweise:
#  - Konstruktion mit $Database = Database->new();
#  - $Database->readData() liest die Datenbank ein
#  - $Database->writeData() schreibt die Datenbank
#  - Die Program Objekte werden im Array @{$Database->programs} gehalten
#
################################################################################

use strict;

use Program;


##############################################
## Konstruktion                             ##
##############################################
sub new {
  my $self = {};

  $self->{FILENAME} = "database.csv";
  $self->{PROGRAMS} = ();

  bless($self);
  return $self;
}


##############################################
## Attribute                                ##
##############################################
sub filename {
  my $self = shift;
  if (@_) { $self->{FILENAME} = shift }
  return $self->{FILENAME};
}
sub programs {
  my $self = shift;
  return $self->{PROGRAMS};
}


##############################################
## Methoden                                 ##
##############################################

# Daten aus CSV Datei einlesen
sub readData {
  my $self = shift;

  # Loesche vorhandene Objekte
  $self->{PROGRAMS} = ();

  # Lese CSV Datei zeilenweise ein und lege
  # Program Objekte an
  my $dir = $0;
  $dir =~ s/\\/\//g;
  $dir = substr($dir, 0, rindex($dir, "/") + 1);

  if ( open(DBFILE, $dir . $self->{FILENAME}) ) {
    while(<DBFILE>) {
      if ( length($_) > 0 ) {
        my $Program = Program->new();
        $Program->csv($_);
        push @{$self->{PROGRAMS}}, $Program;
      }
    }
    close(DBFILE);
  }
}

# Daten in CSV Datei schreiben
sub writeData {
  my $self = shift;

  # Schreibe Program Objekte nach CSV Datei
  my $dir = $0;
  $dir =~ s/\\/\//g;
  $dir = substr($dir, 0, rindex($dir, "/") + 1);

  open(DBFILE, ">" . $dir . $self->{FILENAME}) || die "Fehler: Kann Datei $self->{FILENAME} nicht zum Schreiben oeffnen. ($!)";
  foreach my $Program (@{$self->{PROGRAMS}}) {
   print DBFILE $Program->csv() . "\n";
  }
  close(DBFILE);
}


1;
