#!/bin/perl

################################################################################
# PAD Archiv Demo
# Copyright (c) 2000-2002 by Oliver Grahl Software Design
#
# http://www.o-grahl.de/deupad/
#
# Freeware, Verwendung auf eigene Gefahr.
# Verffentlichung oder Weitergabe nur mit Zustimmung des Autors.
################################################################################
#
# spidern.pl
#
# Zweck:
#  Abrufen der, in der Datenbank gespeicherten PAD Dateien und
#  Aktualisieren der Informationen in der Datenbank
# Funktionsweise:
#  - Liest jede einzelne PAD Datei fr alle Programme in der Datenbank ein
#  - Protokolliert auftretende Fehler
#  - Aktualisiert die Daten zu den Programmen aus den PAD Dateien
#  - Schreibt die aktualisierten Daten zurueck in die Datenbank
#
################################################################################

use lib $ENV{'DOCUMENT_ROOT'} . '/cgi-bin/padarc';  # Siehe readme.txt !!

use Program;
use Database;
use PadFile;


# HTML Kopf ausgeben
print "Content-type: text/html\n\n";

print qq!
<html>

<head>
<title>PAD Archiv Demo - Spidern</title>
</head>

<body><h1>PAD Archiv Demo</h1>
<p><a href="anzeigen.pl">Alle Programme</a> - <a href="anmelden.pl">Programm anmelden</a> - <b>Spidern</b></p>
!;


# Lese Database ein
my $Database = Database->new();
$Database->readData();

# Gehe ueber alle Programme und spidere sie
foreach my $Program (@{$Database->programs()}) {
  print "Lade Datei " . $Program->padurl() . " ... ";

  # Lade die PAD Datei
  my $PadFile = PadFile->new();
  $PadFile->padurl($Program->padurl());
  if ( $PadFile->readContent() ) {
    # PAD Datei konnte gelesen werden

    # Fehlerzaehler und -speicher zuruecksetzen
    $Program->errorcount(0);
    $Program->lasterror("");
    # Program Objekt mit den neuen Daten fuellen
    $Program->padurl($PadFile->getValue("XML_DIZ_INFO", "Web_Info", "Application_URLs", "Application_XML_File_URL"));
    $Program->name($PadFile->getValue("XML_DIZ_INFO", "Program_Info", "Program_Name"));
    $Program->version($PadFile->getValue("XML_DIZ_INFO", "Program_Info", "Program_Version"));
    my $descr = $PadFile->getValue("XML_DIZ_INFO", "Program_Descriptions", "German", "Char_Desc_45");
    if ( $descr eq "" ) { $descr = $PadFile->getValue("XML_DIZ_INFO", "Program_Descriptions", "German", "Char_Desc_80"); };
    if ( $descr eq "" ) { $descr = $PadFile->getValue("XML_DIZ_INFO", "Program_Descriptions", "English", "Char_Desc_45"); };
    if ( $descr eq "" ) { $descr = $PadFile->getValue("XML_DIZ_INFO", "Program_Descriptions", "English", "Char_Desc_80"); };
    $Program->description($descr);

    print "<b><font color=green>OK</font></b><br>";
  }
  else {
    # PAD Datei konnte NICHT gelesen werden

    # Fehlerzaehler inkrementieren und Fehler speichern
    $Program->errorcount($Program->errorcount() + 1);
    $Program->lasterror($PadFile->error());

    print "<b><font color=red>FEHLER: " . $Program->lasterror() . "(" . $Program->errorcount() . ". Fehler in Folge)</font></b><br>";
  }
}


# Schreibe die gesamte Datenbank
$Database->writeData();

print "<br>Das Spidern wurde abgeschlossen, die Datenbank wurde aktualisiert.<br>";


# HTML Fuss ausgeben
print qq!
</body>

</html>
!;
